"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var index_1 = require("./index");
var utils_1 = require("./lib/utils");
describe("repolar", function () {
    var dummyTokenizer = { something: 0 };
    describe("block tokenizers", function () {
        function buildParser(blockMethods, blockTokenizers) {
            if (blockMethods === void 0) { blockMethods = []; }
            if (blockTokenizers === void 0) { blockTokenizers = {}; }
            function Parser() { }
            Parser.prototype.blockMethods = blockMethods.slice();
            Parser.prototype.blockTokenizers = __assign({}, blockTokenizers);
            Parser.prototype.inlineTokenizers = {
                deletion: dummyTokenizer
            };
            Parser.prototype.inlineMethods = ["deletion"];
            return Parser;
        }
        utils_1.forEach(["setextHeading", "definition", "footnote", "indentedCode", "table"], function (tokenizer) {
            test("should remove " + tokenizer + " tokenizer", function () {
                var Parser = buildParser([tokenizer], {
                    tokenizer: dummyTokenizer
                });
                index_1.setBlockTokenizers(Parser);
                expect(Parser.prototype.blockMethods.indexOf(tokenizer)).toBe(-1);
                expect(Parser.prototype.blockTokenizers[tokenizer]).toEqual(undefined);
            });
        });
        test("should update thematicBreak tokenizer", function () {
            var Parser = buildParser(["thematicBreak"], {
                thematicBreak: dummyTokenizer
            });
            index_1.setBlockTokenizers(Parser);
            expect(Parser.prototype.blockTokenizers["thematicBreak"]).not.toEqual(dummyTokenizer);
        });
        test("should add todos tokenizer after list", function () {
            var Parser = buildParser(["list"], {
                list: dummyTokenizer
            });
            index_1.setBlockTokenizers(Parser);
            expect(Parser.prototype.blockTokenizers["todos"]).not.toBe(undefined);
            expect(Parser.prototype.blockMethods).toEqual(["list", "todos"]);
        });
    });
    describe("inline tokenizers", function () {
        function buildParser(inlineMethods, inlineTokenizers) {
            if (inlineMethods === void 0) { inlineMethods = []; }
            if (inlineTokenizers === void 0) { inlineTokenizers = {}; }
            function Parser() { }
            Parser.prototype.blockMethods = [];
            Parser.prototype.blockTokenizers = {};
            Parser.prototype.inlineTokenizers = __assign({ deletion: dummyTokenizer, test: dummyTokenizer, html: dummyTokenizer }, inlineTokenizers);
            Parser.prototype.inlineMethods = [
                "deletion",
                "text",
                "html"
            ].concat(inlineMethods);
            return Parser;
        }
        test("should update deletion tokenizer", function () {
            var Parser = buildParser(["deletion"], {
                deletion: dummyTokenizer
            });
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineTokenizers["deletion"]).not.toEqual(dummyTokenizer);
        });
        test("should update emphasis tokenizer", function () {
            var Parser = buildParser(["emphasis"], {
                emphasis: dummyTokenizer
            });
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineTokenizers["emphasis"]).not.toEqual(dummyTokenizer);
        });
        test("should update strong tokenizer", function () {
            var Parser = buildParser(["strong"], {
                strong: dummyTokenizer
            });
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineTokenizers["strong"]).not.toEqual(dummyTokenizer);
        });
        test("should add highlight tokenizer", function () {
            var Parser = buildParser();
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineMethods.join()).toContain(["text", "highlight"].join());
            expect(Parser.prototype.inlineTokenizers["highlight"]).not.toEqual(dummyTokenizer);
        });
        test("should add hunderline tokenizer", function () {
            var Parser = buildParser();
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineMethods.join()).toContain(["deletion", "underline"].join());
            expect(Parser.prototype.inlineTokenizers["underline"]).not.toEqual(dummyTokenizer);
        });
        test("should remove html tokenizer", function () {
            var Parser = buildParser();
            index_1.setInlineTokenizers(Parser);
            expect(Parser.prototype.inlineMethods).not.toContain("html");
            expect(Parser.prototype.inlineTokenizers["html"]).toBe(undefined);
        });
    });
});
