"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = __importDefault(require("./"));
describe("list", function () {
    var addMock, eatMock, self;
    var position = {
        column: 0,
        offset: 0
    };
    beforeEach(function () {
        addMock = jest.fn(function () { });
        eatMock = jest.fn(function () { return addMock; });
        eatMock.now = jest.fn(function () { return position; });
        self = { tokenizeBlock: jest.fn(function () { return "tokenizeBlock"; }) };
    });
    afterEach(function () {
        addMock.mockReset();
        eatMock.mockReset();
        eatMock.now.mockReset();
        self.tokenizeBlock.mockReset();
    });
    test("should parse valid lists", function () {
        _1.default.bind(self)(eatMock, "* item 1\n* item 2");
        expect(eatMock).lastCalledWith("* item 1\n* item 2");
        expect(addMock).lastCalledWith({
            type: "list",
            ordered: false,
            children: [
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                },
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                }
            ]
        });
        expect(self.tokenizeBlock).toBeCalledWith("item 1", position);
        expect(self.tokenizeBlock).toBeCalledWith("item 2", position);
    });
    test("should parse valid ordered lists", function () {
        _1.default.bind(self)(eatMock, "1. item 1\n1. item 2");
        expect(eatMock).lastCalledWith("1. item 1\n1. item 2");
        expect(addMock).lastCalledWith({
            type: "list",
            ordered: true,
            children: [
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                },
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                }
            ]
        });
        expect(self.tokenizeBlock).toBeCalledWith("item 1", position);
        expect(self.tokenizeBlock).toBeCalledWith("item 2", position);
    });
    test("should parse valid ordered lists regarless the initial number", function () {
        _1.default.bind(self)(eatMock, "2. item 1\n3. item 2");
        expect(eatMock).lastCalledWith("2. item 1\n3. item 2");
        expect(addMock).lastCalledWith({
            type: "list",
            ordered: true,
            start: "2",
            children: [
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                },
                {
                    type: "listItem",
                    children: "tokenizeBlock"
                }
            ]
        });
        expect(self.tokenizeBlock).toBeCalledWith("item 1", position);
        expect(self.tokenizeBlock).toBeCalledWith("item 2", position);
    });
    test("should not parse lists that doesn't start with *", function () {
        _1.default.bind(self)(eatMock, "- item 1\n- item 2");
        expect(eatMock).not.toBeCalled();
    });
    test("should not parse lists that doesn't start with decimal followed by dot", function () {
        _1.default.bind(self)(eatMock, "1) item 1\n1) item 2");
        expect(eatMock).not.toBeCalled();
    });
    test("should not parse strings thats only new lines", function () {
        _1.default.bind(self)(eatMock, "\n\n\n\n\n\n\n\n");
        expect(eatMock).not.toBeCalled();
    });
});
