"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var _1 = __importDefault(require("./"));
describe("todos", function () {
    var addMock, eatMock, self;
    var position = {
        column: 0,
        offset: 0
    };
    beforeEach(function () {
        addMock = jest.fn(function () { });
        eatMock = jest.fn(function () { return addMock; });
        eatMock.now = jest.fn(function () { return position; });
        self = { tokenizeBlock: jest.fn(function () { return "tokenizeBlock"; }) };
    });
    afterEach(function () {
        addMock.mockReset();
        eatMock.mockReset();
        eatMock.now.mockReset();
        self.tokenizeBlock.mockReset();
    });
    test("should parse valid todoss", function () {
        _1.default.bind(self)(eatMock, "- todo 1\n- todo 2\n+ done");
        expect(eatMock).lastCalledWith("- todo 1\n- todo 2\n+ done");
        expect(addMock).lastCalledWith({
            type: "list",
            ordered: false,
            children: [
                {
                    type: "listItem",
                    checked: false,
                    children: "tokenizeBlock"
                },
                {
                    type: "listItem",
                    checked: false,
                    children: "tokenizeBlock"
                },
                {
                    type: "listItem",
                    checked: true,
                    children: "tokenizeBlock"
                }
            ]
        });
        expect(self.tokenizeBlock).toBeCalledWith("todo 1", position);
        expect(self.tokenizeBlock).toBeCalledWith("todo 2", position);
        expect(self.tokenizeBlock).toBeCalledWith("done", position);
    });
    test("should not parse todoss that doesn't start with - or +", function () {
        _1.default.bind(self)(eatMock, "* todo 1\n* todo 2\n* done");
        expect(eatMock).not.toBeCalled();
    });
    test("should not parse strings thats only new lines", function () {
        _1.default.bind(self)(eatMock, "\n\n\n\n\n\n\n\n");
        expect(eatMock).not.toBeCalled();
    });
});
